@@ -133,7 +133,7 @@ synchSet('groupBase',"ou=group,dc=wong,dc=dom");
 
 synchSet('ScriptPath',"/opt/scripts/");
 
-synchSet('dn',"cn={myName},{peopleBase}");
+synchSet('dn',"uid={myName},{peopleBase}");
 
 synchSet('abort',false);					// set to true if subsequent functions should be aborted
 synchSet('abortReason',"unknown");
@@ -379,6 +379,11 @@ function synchLdapDelete() {
 	return ldap_delete($ldapconfig['ds'],synchGetTranslated('dn'));
 }
 
+function synchLdapInsert($dn,$att) {
+	global $ldapconfig;
+	return ldap_mod_add($ldapconfig['ds'],$dn,$att);
+}
+
 function synchLdapReplace($att) {
 	global $ldapconfig;
 	return ldap_mod_replace($ldapconfig['ds'],synchGetTranslated('dn'),$att);
@@ -406,8 +411,12 @@ function synchLdapCreate(){
 	global $ldapconfig;
 	// perform add
 	synchLdapOpen();
-	if(!synchLdapAdd(synchTranslateArray($ldapconfig['add']['ldif'])))
+	if(synchLdapAdd(synchTranslateArray($ldapconfig['add']['ldif']))){
+		synchSet('ldifResult',1);
+	} else {
+		synchSet('ldifResult',0);
 		synchLog("LDAP create for {myName} failed");
+	}
 	synchLdapClose();
 
 	synchCreateNukeUser();
@@ -417,8 +426,12 @@ function synchLdapCreate(){
 function synchLdapDestroy(){
 	global $ldapconfig;
 	synchLdapOpen();
-	if(!synchLdapDelete())
+	if(synchLdapDelete()){
+		synchSet('ldifResult',1);
+	} else {
+		synchSet('ldifResult',0);
 		synchLog("LDAP delete for {myName} failed");
+	}
 	synchLdapClose();
 }
 
@@ -501,6 +514,7 @@ function synchMapState(){
 	synchMapCall('callLast');
 
 	if(synchGet('abort')){
+	die('aborted');
 	        synchSet('abortedState',synchGet('myState'));
 	        synchSet('myState','abort');
 		synchMapLog();
